@@ -1,5 +1,5 @@
 from .enums import Color, Icon, Precision, Keyboard, TextAlignment, SliderBarType, DialPosition, DialStyle, \
-    GraphLineType, TimeGraphLineType, MapType, TimeGraphTimeScale, TimeGraphPositionOfKey, ButtonState, LabelStyle
+    GraphLineType, TimeGraphLineType, TimeGraphPositionOfKey, ButtonState, LabelStyle, KnobStyle, GraphXAxisLabelsStyle
 from .graph import Graph, GraphLine
 from .slider_single_bar import SliderSingleBar
 from .slider_double_bar import SliderDoubleBar
@@ -9,7 +9,7 @@ from .time_graph import TimeGraph, TimeGraphLine, DataPoint
 from .knob import Knob
 from .dial import Dial
 from .compass import Compass
-from .map import Map, MapLocation
+from .map import Map, MapLocation, SimpleMapLocation
 from .alarm import Alarm
 from .menu import Menu
 from .selector import Selector
