@@ -1,5 +1,5 @@
 from .control import Control
-from .enums import Icon
+from .enums import Icon, TitlePosition
 from .button import Button
 
 
@@ -7,25 +7,18 @@ class ButtonGroup(Control):
     def get_state(self):
         return ""
 
-    def __get_button_group_state(self, msg):
-        button_group_status = ""
-        for key in self.control_dict.keys():
-            button_group_status += self.control_dict[key].get_state()
-        self.state_str = button_group_status
-
     def __init__(
         self,
         control_id,
         title="A Button Group",
         text="A Button group with Text",
+        title_position=TitlePosition.BOTTOM,
         icon=Icon.MENU,
         grid_view=True,
         control_position=None,
     ):
-        super().__init__("BTGP", control_id, control_position=control_position)
+        super().__init__("BTGP", control_id, control_position=control_position, title_position=title_position)
         self.title = title
-        self.control_list = []
-        self.control_dict = {}
         self._state_str = "\t{}\t{}\t".format(self.msg_type, self.control_id)
         self.icon_name = icon
         self.text = text
