@@ -1,4 +1,4 @@
-from .enums import Color
+from .enums import Color, TitlePosition
 from .control import Control
 
 import datetime
@@ -6,27 +6,28 @@ import dateutil.parser
 
 
 class EventData:
-    def __init__(self, header, body, color=Color.BLACK):
+    def __init__(self, header, body, color=Color.WHITE):
         self.color = color
         self.timestamp = datetime.datetime.utcnow().replace(microsecond=0, tzinfo=datetime.timezone.utc)
         self.header = header
         self.body = body
 
     def to_string(self):
-        data_str = "{ts}\t{Color}\t{header}\t{body}\n".format(
-            ts=self.timestamp.isoformat(), color=self.color, header=self.header, body=self.body
+        data_str = "{ts}\t{color}\t{header}\t{body}\n".format(
+            ts=self.timestamp.isoformat(), color=str(self.color.value), header=self.header, body=self.body
         )
         return data_str
 
+
 # TODO: Finish the Event log
 class EventLog(Control):
     def get_state(self):
         state_str = ""
         return state_str
 
-    def __init__(self, control_id, title="An Event Log", control_position=None):
-        super().__init__("LOG", control_id, control_position=control_position)
-
+    def __init__(self, control_id, title="An Event Log", title_position=TitlePosition.BOTTOM, control_position=None):
+        super().__init__("LOG", control_id, control_position=control_position, title_position=title_position)
+        self.title = title
         self.message_rx_event += self.__get_log_from_timestamp
 
         self.log_list = []
@@ -34,7 +35,7 @@ class EventLog(Control):
 
     def __get_log_from_timestamp(self, msg):
 
-        dt = dateutil.parser.isoparse(msg[0])
+        dt = dateutil.parser.isoparse(msg[3])
         data_str = ""
         for log in self.log_list:
             if log.timestamp > dt:
@@ -46,11 +47,6 @@ class EventLog(Control):
             self.log_list.append(data)
             self.state_str = self.get_state_str + data.to_string()
 
-    def add_event_data(self, header, body, color=Color.BLACK):
-        nl = EventData(header, body, color=color)
-        self.log_list.append(nl)
-        self.state_str = self.get_state_str + nl.to_string()
-
     def send_data(self):
         if self.log_list:
             self.state_str = self.get_state_str + self.log_list[-1].to_string()
