@@ -1,4 +1,4 @@
-from .enums import Color, LabelStyle
+from .enums import Color, LabelStyle, TitlePosition
 from .control import Control
 
 
@@ -8,15 +8,14 @@ class Label(Control):
     def __init__(
         self,
         control_id,
-        control_title="A label",
-        text="",
+        title="A label",
+        title_position=TitlePosition.BOTTOM,
         color=Color.WHITE,
         style=LabelStyle.BASIC,
         control_position=None,
     ):
-        super().__init__("LBL", control_id, control_position=control_position)
-        self.title = control_title
-        self.text = text
+        super().__init__("LBL", control_id, control_position=control_position, title_position=title_position)
+        self.title = title
         self.color = color
         self.style = style
         self._state_str = ""
@@ -36,12 +35,5 @@ class Label(Control):
 
     @color.setter
     def color(self, val: Color):
+        self._color = val
         self._cfg["Color"] = str(val.value)
-
-    @property
-    def text(self):
-        return self._cfg["text"]
-
-    @text.setter
-    def text(self, val):
-        self._cfg["text"] = val
